==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebTreeSelectionOptionsEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeSelectionOptionsEventDetailDescriptionMetadata } from "./WebTreeSelectionOptionsEventDetailDescriptionMetadata";
import { WebTreeSelectionOptionsEventArgsDescription } from "./WebTreeSelectionOptionsEventArgsDescription";
/**
 * @hidden
 */
export let WebTreeSelectionOptionsEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTreeSelectionOptionsEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebTreeSelectionOptionsEventArgsDescriptionMetadata.a == null) {
                WebTreeSelectionOptionsEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTreeSelectionOptionsEventArgsDescriptionMetadata.c(WebTreeSelectionOptionsEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebTreeSelectionOptionsEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebTreeSelectionOptionsEventArgsDescriptionMetadata.a);
            WebTreeSelectionOptionsEventDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TreeSelectionOptionsEventArgs");
            a.item("Detail", "ExportedType:WebTreeSelectionOptionsEventDetail");
        }
        static d(a) {
            WebTreeSelectionOptionsEventArgsDescriptionMetadata.b(a);
            a.aa("WebTreeSelectionOptionsEventArgs", () => new WebTreeSelectionOptionsEventArgsDescription());
            a.z("WebTreeSelectionOptionsEventArgs", WebTreeSelectionOptionsEventArgsDescriptionMetadata.a);
        }
    }
    WebTreeSelectionOptionsEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTreeSelectionOptionsEventArgsDescriptionMetadata, 'WebTreeSelectionOptionsEventArgsDescriptionMetadata');
    WebTreeSelectionOptionsEventArgsDescriptionMetadata.a = null;
    return WebTreeSelectionOptionsEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebTreeSelectionOptionsEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeSelectionOptionsEventDetailDescriptionMetadata } from "./WebTreeSelectionOptionsEventDetailDescriptionMetadata";
import { WebTreeSelectionOptionsEventArgsDescription } from "./WebTreeSelectionOptionsEventArgsDescription";
/**
 * @hidden
 */
export let WebTreeSelectionOptionsEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTreeSelectionOptionsEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebTreeSelectionOptionsEventArgsDescriptionMetadata.a == null) {
                WebTreeSelectionOptionsEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTreeSelectionOptionsEventArgsDescriptionMetadata.c(WebTreeSelectionOptionsEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebTreeSelectionOptionsEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebTreeSelectionOptionsEventArgsDescriptionMetadata.a);
            WebTreeSelectionOptionsEventDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TreeSelectionOptionsEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Detail", "ExportedType:WebTreeSelectionOptionsEventDetail");
        }
        static d(a) {
            WebTreeSelectionOptionsEventArgsDescriptionMetadata.b(a);
            a.ac("WebTreeSelectionOptionsEventArgs", () => new WebTreeSelectionOptionsEventArgsDescription());
            a.ab("WebTreeSelectionOptionsEventArgs", WebTreeSelectionOptionsEventArgsDescriptionMetadata.a);
        }
    }
    WebTreeSelectionOptionsEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTreeSelectionOptionsEventArgsDescriptionMetadata, 'WebTreeSelectionOptionsEventArgsDescriptionMetadata');
    WebTreeSelectionOptionsEventArgsDescriptionMetadata.a = null;
    return WebTreeSelectionOptionsEventArgsDescriptionMetadata;
})();
